@@ -2,7 +2,7 @@
 /*
 Plugin Name: CiviCRM
 Description: CiviCRM - Growing and Sustaining Relationships
-Version: 5.24.6
+Version: 5.25.0
 Author: CiviCRM LLC
 Author URI: https://civicrm.org/
 Plugin URI: https://docs.civicrm.org/sysadmin/en/latest/install/wordpress/
@@ -54,7 +54,7 @@ if ( ! defined( 'ABSPATH' ) ) exit;
 
 
 // Set version here: when it changes, will force JS to reload
-define( 'CIVICRM_PLUGIN_VERSION', '5.24.6' );
+define( 'CIVICRM_PLUGIN_VERSION', '5.25.0' );
 
 // Store reference to this file
 if (!defined('CIVICRM_PLUGIN_FILE')) {
@@ -75,15 +75,16 @@ if ( !defined( 'CIVICRM_WP_PHP_MINIMUM' ) ) {
   /**
    * Minimum required PHP
    *
-   * Note: This duplicates CRM_Upgrade_Form::MINIMUM_PHP_VERSION. The
-   * duplication helps avoid dependency issues. (Reading `Form::MINIMUM_PHP_VERSION`
-   * requires loading `civicrm.settings.php`, but that triggers a parse-error
+   * Note: This duplicates CRM_Upgrade_Incremental_General::MIN_INSTALL_PHP_VER.
+   * The duplication helps avoid dependency issues. (Reading
+   * `CRM_Upgrade_Incremental_General::MIN_INSTALL_PHP_VER` requires loading
+   * `civicrm.settings.php`, but that triggers a parse-error
    * on PHP 5.x.)
    *
-   * @see CRM_Upgrade_Form::MINIMUM_PHP_VERSION
+   * @see CRM_Upgrade_Incremental_General::MIN_INSTALL_PHP_VER
    * @see CiviWP\PhpVersionTest::testConstantMatch()
    */
-  define( 'CIVICRM_WP_PHP_MINIMUM', '7.0.0' );
+  define( 'CIVICRM_WP_PHP_MINIMUM', '7.1.0' );
 }
 
 /*
@@ -121,6 +122,17 @@ if ( file_exists( CIVICRM_SETTINGS_PATH )  ) {
 // Prevent CiviCRM from rendering its own header
 define( 'CIVICRM_UF_HEAD', TRUE );
 
+/**
+ * Setting this to 'true' will replace all mailing URLs calls to 'extern/url.php'
+ * and 'extern/open.php' with their REST counterpart 'civicrm/v3/url' and 'civicrm/v3/open'.
+ *
+ * Use for test purposes, may affect mailing
+ * performance, see Plugin->replace_tracking_urls() method.
+ */
+if ( ! defined( 'CIVICRM_WP_REST_REPLACE_MAILING_TRACKING' ) ) {
+  define( 'CIVICRM_WP_REST_REPLACE_MAILING_TRACKING', false );
+}
+
 
 /**
  * Define CiviCRM_For_WordPress Class.
@@ -356,6 +368,9 @@ class CiviCRM_For_WordPress {
     if (empty($civicrm_paths['cms.root']['path'])) {
       $civicrm_paths['cms.root']['path'] = untrailingslashit(ABSPATH);
     }
+    if (empty($civicrm_paths['cms.root']['url'])) {
+      $civicrm_paths['cms.root']['url'] = home_url();
+    }
 
     // Get classes and instantiate
     $this->include_files();
@@ -512,6 +527,11 @@ class CiviCRM_For_WordPress {
     include_once CIVICRM_PLUGIN_DIR . 'includes/civicrm.basepage.php';
     $this->basepage = new CiviCRM_For_WordPress_Basepage;
 
+    if ( ! class_exists( 'CiviCRM_WP_REST\Autoloader' ) ) {
+      // Include REST API autoloader class
+      require_once( CIVICRM_PLUGIN_DIR . 'wp-rest/Autoloader.php' );
+    }
+
   }
 
 
@@ -636,6 +656,16 @@ class CiviCRM_For_WordPress {
     // Register hooks for clean URLs.
     $this->register_hooks_clean_urls();
 
+    if ( ! class_exists( 'CiviCRM_WP_REST\Plugin' ) ) {
+
+      // Set up REST API.
+      CiviCRM_WP_REST\Autoloader::add_source( $source_path = trailingslashit( CIVICRM_PLUGIN_DIR . 'wp-rest' ) );
+
+      // Init REST API.
+      new CiviCRM_WP_REST\Plugin;
+
+    }
+
   }
 
 
